@@ -2,7 +2,7 @@
 from .clients import Chat_Bot_Client
 
 # Base classes / mixins
-from .base import OpenAPI_Client
+from .base import OpenAI_Client
 from .mixins import Chat_Context_Manager_Mixin
 
 # Enums
